
package uicc.contactmanager;
/**
 * Listener interface to react to contact manager events.<br>
 */
public interface ContactEventListener {
    /**
     * This event indicates that a new contact has been added 
     * to the contact list.
     */
    public static final int EVENT_CONTACT_ADDED = 1;

    /**
     * This event indicates that a contact has been modified.
     */
    public static final int EVENT_CONTACT_MODIFIED = 2;

    /**
     * This event indicates that a contact has been 
     * removed from the contact list.
     */
    public static final int EVENT_CONTACT_REMOVED = 3;

    /**
     * contactModified is called when a contact is added/removed/updated in the contact list.
     * 
     * @param event represents the type of event that occurs:<br>
     * 			EVENT_CONTACT_ADDED,EVENT_CONTACT_MODIFIED,EVENT_CONTACT_REMOVED
     * @param contactIdentifier represent the id of the contact modified 
     * 
     */
    public void contactModified(int event, int contactIdentifier) ;


    /**
     * This event indicates that a new group has been added to the groups list.
     */
    public static final int EVENT_GROUP_ADDED = 4;

    /**
     * This event indicates that a group has been removed from the groups list.
     */
    public static final int EVENT_GROUP_REMOVED = 6;

    /**
     * This event indicates that a new contact has been added to a group.
     */
    public static final int EVENT_GROUP_CONTACT_ADDED = 7;

    /**
     * This event indicates that a contact has been removed from a group.
     */
    public static final int EVENT_GROUP_CONTACT_REMOVED = 8;

    /**
     * groupModified is called when a group is added/removed/updated in the groups list
     * or when a contact is added/removed from any group in the groups list.
     * 
     * @param event represents the type of event that occurs:<br>
     *          EVENT_GROUP_ADDED, EVENT_GROUP_REMOVED, EVENT_GROUP_CONTACT_ADDED, EVENT_GROUP_CONTACT_REMOVED          
     *     
     * @param groupIdentifier represents the id of the group that is added,removed or modified
     * @param contactIdentifier represents the id of the contact that is added or removed from the group 
     * 
     */
    public void groupModified(int event, int groupIdentifier,int contactIdentifier) ;



    /**
     * This event indicates that a new field descriptor has been added.
     */
    public static final int EVENT_FIELD_DESCRIPTOR_ADDED = 9;

    /**
     * This event indicates that a field descriptor has been modified.
     */
    public static final int EVENT_FIELD_DESCRIPTOR_MODIFIED = 10;

    /**
     * This event indicates that a field descriptor has been removed.
     */
    public static final int EVENT_FIELD_DESCRIPTOR_REMOVED = 11;

    /**
     * fieldDescriptorModified is called when a field descriptor is added/removed/updated from the field descriptor list.
     * 
     * @param event represents the type of event that occurs:<br>
     * 			EVENT_FIELD_DESCRIPTOR_ADDED, EVENT_FIELD_DESCRIPTOR_MODIFIED, EVENT_FIELD_DESCRIPTOR_REMOVED
     * 
     * @param fieldDescriptorIdentifier represents the id of the modified field descriptor
     * 
     */
    public void fieldDescriptorModified(int event, int fieldDescriptorIdentifier) ;
}
